@@ -147,21 +147,6 @@
 #' 
 #' @author Jeffrey Horner
 #' 
-#' @references
-#' Please refer to your institution's API documentation.
-#' 
-#' Additional details on API parameters are found on the package wiki at
-#' \url{https://github.com/nutterb/redcapAPI/wiki/REDCap-API-Parameters}
-#' 
-#' This functionality were originally developed by Jeffrey Horner in the \code{redcap} package.
-#' \url{https://github.com/vubiostat/redcap}
-#' 
-#' See also \code{read_redcap_oneshot} in the \code{REDCapR} package by Will Beasley.
-#' \url{https://github.com/OuhscBbmc/REDCapR}
-#' 
-#' Borrowed code from http://stackoverflow.com/a/8099431/1017276 to 
-#' create a list of arbitrary length.
-#' 
 #' @export
 
 exportRecords <-
@@ -378,11 +363,15 @@ exportRecords.redcapApiConnection <-
                   checkboxLabels = checkboxLabels)
 
   if (labels){
-    x[suffixed$name_suffix] <-
+    x[,suffixed$name_suffix] <-
       mapply(nm = suffixed$name_suffix,
              lab = suffixed$label_suffix,
              FUN = function(nm, lab){
-               labelVector::set_label(x[[nm]], lab)
+               if(is.null(x[[nm]])){
+                  warning("Missing field for suffix ", nm)
+               } else {
+                  labelVector::set_label(x[[nm]], lab)
+               }
              },
              SIMPLIFY = FALSE)
   }
