@@ -109,11 +109,15 @@ exportRecords_offline <- function(dataFile, metaDataFile,
                   checkboxLabels = checkboxLabels)
   
   if (labels){
-    x[suffixed$name_suffix] <-
+    x[,suffixed$name_suffix] <-
       mapply(nm = suffixed$name_suffix,
              lab = suffixed$label_suffix,
              FUN = function(nm, lab){
-               labelVector::set_label(x[[nm]], lab)
+               if(is.null(x[[nm]])){
+                 warning("Missing field for suffix ", nm)
+               } else {
+                 labelVector::set_label(x[[nm]], lab)
+               }
              },
              SIMPLIFY = FALSE)
   }
