@@ -170,7 +170,11 @@ exportReports.redcapApiConnection <- function(rcon, report_id, factors = TRUE, l
       mapply(nm = suffixed$name_suffix,
              lab = suffixed$label_suffix,
              FUN = function(nm, lab){
-               labelVector::set_label(x[[nm]], lab)
+               if(is.null(x[[nm]])){
+                 warning("Missing field for suffix ", nm)
+               } else {
+                 labelVector::set_label(x[[nm]], lab)
+               }
              },
              SIMPLIFY = FALSE)
   }
